@@ -27,6 +27,7 @@
 #include <string.h>
 #include <signal.h>
 #include <sys/wait.h>
+#include <libgen.h>
 
 #include "list.h"
 #include "logger.h"
@@ -109,6 +110,8 @@ static int fs_create(envid_t veid, fs_param *fs, tmpl_param *tmpl,
 		logger(-1, 0, "Error: diskspace not set (required for ploop)");
 		return VZ_DISKSPACE_NOT_SET;
 	}
+	if (ploop && check_ploop_size(dq->diskspace[1]) < 0)
+		return VZ_DISKSPACE_NOT_SET;
 find:
 	for (i = 0; ext[i] != NULL; i++) {
 		snprintf(tarball, sizeof(tarball), "%s/cache/%s.tar%s",
@@ -375,7 +378,7 @@ int vps_create(vps_handler *h, envid_t veid, vps_param *vps_p, vps_param *cmd_p,
 	if (tmpl->ostmpl != NULL) {
 		if (cmd_p->res.tmpl.ostmpl != NULL)
 			free(cmd_p->res.tmpl.ostmpl);
-		cmd_p->res.tmpl.ostmpl = strdup(tmpl->ostmpl);
+		cmd_p->res.tmpl.ostmpl = strdup(basename(tmpl->ostmpl));
 	}
 	if ((ret = vps_save_config(veid, dst, cmd_p, vps_p, action)))
 		goto err_names;
