@@ -39,21 +39,7 @@
 #include "image.h"
 #include "script.h"
 
-/** Function called on CT start to setup resource management
- *
- */
-int setup_resource_management(vps_handler *h, envid_t veid, vps_res *res)
-{
-	int ret;
-
-	if ((ret = check_ub(&res->ub)))
-		return ret;
-	if ((ret = set_ublimit(h, veid, &res->ub)))
-		return ret;
-	return 0;
-}
-
-int fill_2quota_param(struct setup_env_quota_param *p,
+static int fill_2quota_param(struct setup_env_quota_param *p,
 		const char *ve_private, const char *ve_root)
 {
 	struct stat st;
@@ -94,7 +80,7 @@ static int vps_2quota_perm(vps_handler *h, int veid, dev_t device)
 
 	dev.dev = device;
 	dev.type = S_IFBLK | VE_USE_MINOR;
-	dev.mask = S_IRWXG;
+	dev.mask = S_IXGRP;
 	return set_devperm(h, veid, &dev);
 }
 
@@ -134,7 +120,7 @@ int vps_setup_res(vps_handler *h, envid_t veid, dist_actions *actions,
 		return ret;
 	if ((ret = vps_set_fs(fs, &res->fs)))
 		return ret;
-	if((ret = vps_meminfo_set(h, veid, &res->meminfo, param, vps_state)))
+	if ((ret = vps_meminfo_set(h, veid, &res->meminfo, param, vps_state)))
 		return ret;
 	if ((ret = ve_ioprio_set(h, veid, &res->io)))
 		return ret;
