@@ -101,8 +101,7 @@ int read_script(const char *fname, char *include, char **buf)
 err:
 	if (fd > 0)
 		close(fd);
-	if (*buf != NULL)
-		free(*buf);
+	free(*buf);
 	return -1;
 }
 
@@ -165,7 +164,7 @@ int run_script(const char *f, char *argv[], char *env[], int quiet)
 		execve(f, argv, envp);
 		logger(-1, errno, "Error exec %s", f);
 		exit(1);
-	} else if(child == -1) {
+	} else if (child == -1) {
 		logger(-1, errno, "Unable to fork");
 		ret = VZ_RESOURCE_ERROR;
 		goto err;
@@ -278,7 +277,9 @@ int setup_env_quota(const struct setup_env_quota_param *param)
 	if (param->dev_name[0] == '\0') /* simfs/vzquota */
 		return mk_vzquota_link();
 	/* ploop */
-	return mk_quota_dev(param->dev_name, param->dev);
+	if (mk_quota_dev(param->dev_name, param->dev))
+		return -1;
+	return system("quotaon -a");
 }
 
 #define INITTAB_FILE		"/etc/inittab"
