@@ -69,13 +69,14 @@ static void usage(int rc)
 "vzctl destroy | mount | umount | stop | restart | status <ctid>\n"
 "vzctl convert <ctid> [--layout ploop[:mode]] [--diskspace <kbytes>]\n"
 "vzctl quotaon | quotaoff | quotainit <ctid>\n"
-"vzctl console <ctid>\n"
+"vzctl console <ctid> [ttyno]\n"
 "vzctl enter <ctid> [--exec <command> [arg ...]]\n"
 "vzctl exec | exec2 <ctid> <command> [arg ...]\n"
 "vzctl runscript <ctid> <script>\n"
 "vzctl chkpnt <ctid> [--dumpfile <name>]\n"
 "vzctl restore <ctid> [--dumpfile <name>]\n"
 "vzctl set <ctid> [--save] [--force] [--setmode restart|ignore]\n"
+"   [--ram <bytes>[KMG]] [--swap <bytes>[KMG]]\n"
 "   [--ipadd <addr>] [--ipdel <addr>|all] [--hostname <name>]\n"
 "   [--nameserver <addr>] [--searchdomain <name>]\n"
 "   [--onboot yes|no] [--bootorder <N>]\n"
@@ -207,8 +208,7 @@ int main(int argc, char *argv[], char *envp[])
 		action = ACTION_QUOTAOFF;
 	} else if (!strcmp(argv[1], "quotainit")) {
 		action = ACTION_QUOTAINIT;
-	} else if (!strcmp(argv[1], "snapshot-create") ||
-			!strcmp(argv[1], "snapshot")) {
+	} else if (!strcmp(argv[1], "snapshot")) {
 		action = ACTION_SNAPSHOT_CREATE;
 	} else if (!strcmp(argv[1], "snapshot-switch")) {
 		action = ACTION_SNAPSHOT_SWITCH;
